@@ -1,7 +1,9 @@
 // Copyright 2020 New Relic Corporation. All rights reserved.
 // SPDX-License-Identifier: Apache-2.0
 
+//go:build go1.9
 // +build go1.9
+
 // This build tag is necessary because Infinite Tracing is only supported for Go version 1.9 and up
 
 package newrelic
@@ -258,6 +260,12 @@ func TestTraceObserverRestart(t *testing.T) {
 	waitForTrObs(t, to)
 	defer s.Close()
 
+	// Make sure the server has received the new data
+	to.consumeSpan(&spanEvent{})
+	if !s.DidSpansArrive(t, 1, 150*time.Millisecond) {
+		t.Error("Did not receive expected spans before timeout -- before restart")
+	}
+
 	s.ExpectMetadata(t, map[string]string{
 		"agent_run_token": runToken,
 		"license_key":     testLicenseKey,
@@ -268,8 +276,8 @@ func TestTraceObserverRestart(t *testing.T) {
 
 	// Make sure the server has received the new data
 	to.consumeSpan(&spanEvent{})
-	if !s.DidSpansArrive(t, 1, 50*time.Millisecond) {
-		t.Error("Did not receive expected spans before timeout")
+	if !s.DidSpansArrive(t, 1, 150*time.Millisecond) {
+		t.Error("Did not receive expected spans before timeout -- after restart")
 	}
 
 	s.ExpectMetadata(t, map[string]string{
@@ -894,7 +902,7 @@ func TestTrObsOKSendBackoffNo(t *testing.T) {
 	}
 	// If the default backoff of 15 seconds is used, the second span will not
 	// be received in time.
-	if !s.DidSpansArrive(t, 2, time.Second) {
+	if !s.DidSpansArrive(t, 2, 4*time.Second) {
 		t.Error("server did not receive 2 spans")
 	}
 }
